==> open-xchange-documents-ui_7.8.3.orig.tar.bz2: open-xchange-documents-ui-7.8.3/ui/apps/io.ox/office/editframework/view/control/acquireeditbutton.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/editframework/view/control/acquireeditbutton', [
    'io.ox/office/tk/utils',
    'io.ox/office/tk/control/button',
    'io.ox/office/editframework/view/editlabels',
    'gettext!io.ox/office/editframework/main'
], function (Utils, Button, Labels, gt) {

    'use strict';

    // class AcquireEditButton ================================================

    /**
     * A button used to acquire edit rights for the document.
     *
     * @constructor
     *
     * @extends Button
     *
     * @param {EditView} docView
     *  The document view instance containing this control.
     */
    function AcquireEditButton(docView, initOptions) {

        var // self reference
            self = this,

            // timer that stops the animation after a delay
            timer = null;

        // base constructor ---------------------------------------------------

        initOptions = Utils.extendOptions({
            icon: Labels.EDIT_ICON,
            label: Labels.EDIT_SHORT_LABEL,
            tooltip: gt('Acquire edit rights'),
            smallerVersion: { hideLabel: true }
        }, initOptions);
        Button.call(this, initOptions);

        // private methods ----------------------------------------------------

        /**
         * Starts the spinning animation while edit rights are being acquired.
         */
        function startAnimation() {
            stopAnimation();
            self.setIcon('fa-refresh', { classes: 'fa-spin' });
        }

        /**
         * Stops the spinning animation shown while edit rights are being
         * acquired.
         */
        function stopAnimation() {
            if (timer) { timer.abort(); timer = null; }
            self.setIcon(initOptions.icon);
        }

        // initialization -----------------------------------------------------

        // start and stop the spinning animation
        this.listenTo(docView.getApp(), 'docs:editrights:acquire', startAnimation);
        this.listenTo(docView.getApp(), 'docs:editrights:decline', stopAnimation);
        this.listenTo(docView.getDocModel(), 'change:editmode', stopAnimation);

        // destroy class members on destruction
        this.registerDestructor(function () {
            stopAnimation();
            docView = initOptions = self = null;
        });

    } // class AcquireEditButton

    // exports ================================================================

    // derive this class from class Button
    return Button.extend({ constructor: AcquireEditButton });

});

==> open-xchange-documents-ui_7.10.0.orig.tar.bz2: open-xchange-documents-ui-7.10.0/ui/apps/io.ox/office/editframework/view/control/acquireeditbutton.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/editframework/view/control/acquireeditbutton', [
    'io.ox/office/tk/utils',
    'io.ox/office/tk/control/button',
    'io.ox/office/editframework/view/editlabels',
    'gettext!io.ox/office/editframework/main'
], function (Utils, Button, Labels, gt) {

    'use strict';

    // class AcquireEditButton ================================================

    /**
     * A button used to acquire edit rights for the document.
     *
     * @constructor
     *
     * @extends Button
     *
     * @param {EditView} docView
     *  The document view instance containing this control.
     */
    function AcquireEditButton(docView, initOptions) {

        // self reference
        var self = this;

        // timer that stops the animation after a delay
        var timer = null;

        // base constructor ---------------------------------------------------

        initOptions = Utils.extendOptions({
            icon: Labels.EDIT_ICON,
            label: Labels.EDIT_SHORT_LABEL,
            tooltip: gt('Acquire edit rights'),
            smallerVersion: { hideLabel: true }
        }, initOptions);
        Button.call(this, docView, initOptions);

        // private methods ----------------------------------------------------

        /**
         * Starts the spinning animation while edit rights are being acquired.
         */
        function startAnimation() {
            stopAnimation();
            self.setIcon('fa-refresh', { classes: 'fa-spin' });
        }

        /**
         * Stops the spinning animation shown while edit rights are being
         * acquired.
         */
        function stopAnimation() {
            if (timer) { timer.abort(); timer = null; }
            self.setIcon(initOptions.icon);
        }

        // initialization -----------------------------------------------------

        // start and stop the spinning animation
        this.listenTo(docView.getApp(), 'docs:editrights:acquire', startAnimation);
        this.listenTo(docView.getApp(), 'docs:editrights:decline docs:editmode:enter', stopAnimation);

        // destroy class members on destruction
        this.registerDestructor(function () {
            stopAnimation();
            docView = initOptions = self = null;
        });

    } // class AcquireEditButton

    // exports ================================================================

    // derive this class from class Button
    return Button.extend({ constructor: AcquireEditButton });

});
